@@ -26,6 +26,14 @@ namespace netCDF
 	    replace,	//!< Create new file, even if already exists.
 	    newFile	//!< Create new file, fail if already exists.
 	 };
+
+      enum FileFormat
+         {
+	    classic,    //!< Classic format, classic data model
+	    classic64,  //!< 64-bit offset format, classic data model
+	    nc4,        //!< (default) netCDF-4/HDF5 format, enhanced data model
+	    nc4classic  //!< netCDF-4/HDF5 format, classic data model
+         };
     
       /*! assignment operator  */
       NcFile& operator =(const NcGroup & rhs);
@@ -49,6 +57,15 @@ namespace netCDF
 	                    - 'newFile' Create new file, fail it exists already.
       */
       NcFile(const std::string& filePath, FileMode fMode);
+
+      /*! 
+	Creates a netCDF file of a specified format.
+	\param filePath    Name of netCDF optional path.
+	\param fMode       The file mode:
+	                    - 'replace' Create new file, even it already exists.
+	                    - 'newFile' Create new file, fail it exists already.
+      */
+      NcFile(const std::string& filePath, FileMode fMode, FileFormat fFormat);
     
       /*! destructor */
       virtual ~NcFile(); //closes file and releases all resources
