@@ -1,8 +1,9 @@
-! This is part of netCDF-4. Copyright 2006 UCAR. See COPYRIGHT file for details.
+! This is part of netCDF-4. Copyright 2006 UCAR. See COPYRIGHT file
+! for details.
 
 ! This file contains the extra F90 constants needed for netCDF-4.
 
-! $Id: netcdf4_constants.f90,v 1.13 2009/12/10 16:43:15 ed Exp $
+! $Id: netcdf4_constants.f90,v 1.14 2010/05/25 13:53:00 ed Exp $
 
 ! extra data types:
 integer, parameter, public :: &
@@ -36,6 +37,10 @@ integer, parameter, public :: &
 
 ! Flags for parallel access.
 integer, parameter, public :: nf90_independent = 0, nf90_collective = 1
+
+! Flags for parallel I/O.
+integer, parameter, public :: nf90_mpiio = 8192, nf90_mpiposix = 16384, &
+     nf90_pnetcdf = 32768
   
 ! Extra variable flags.
 integer, parameter, public :: &
