@@ -2,24 +2,93 @@
   ! NetCDF-4 extra routines:
   !
   ! -----------
-  function nf90_create_par(path, cmode, comm, info, ncid)
+  function nf90_create_par(path, cmode, comm, info, ncid, cache_size, &
+       cache_nelems, cache_preemption)
     character (len = *), intent(in) :: path
     integer, intent(in) :: cmode
     integer, intent(in) :: comm
     integer, intent(in) :: info
     integer, intent(out) :: ncid
+    integer, optional, intent(in) :: cache_size, cache_nelems
+    real, optional, intent(in) :: cache_preemption
+    integer :: size_in, nelems_in, preemption_in
+    integer :: size_out, nelems_out, preemption_out, ret
     integer :: nf90_create_par
+    
+    ! If the user specified chuck cache parameters, use them. But user
+    ! may have specified one, two, or three settings. Leave the others
+    ! unchanged.
+    if (present(cache_size) .or. present(cache_nelems) .or. &
+         present(cache_preemption)) then
+       ret = nf_get_chunk_cache(size_in, nelems_in, preemption_in)
+       if (ret .ne. nf90_noerr) then
+          nf90_create_par = ret
+          return
+       end if
+       if (present(cache_size)) then
+          size_out = cache_size
+       else
+          size_out = size_in
+       end if
+       if (present(cache_nelems)) then
+          nelems_out = cache_nelems
+       else
+          nelems_out = nelems_in
+       end if
+       if (present(cache_preemption)) then
+          preemption_out = cache_preemption
+       else
+          preemption_out = preemption_in
+       end if
+       nf90_create_par = nf_set_chunk_cache(size_out, nelems_out, preemption_out)
+       if (nf90_create_par .ne. nf90_noerr) return
+    end if 
+
     nf90_create_par = nf_create_par(path, cmode, comm, info, ncid)
   end function nf90_create_par
   ! -----------
-  function nf90_open_par(path, cmode, comm, info, ncid)
+  function nf90_open_par(path, cmode, comm, info, ncid, cache_size, &
+       cache_nelems, cache_preemption)
     character (len = *), intent(in) :: path
     integer, intent(in) :: cmode
     integer, intent(in) :: comm
     integer, intent(in) :: info
     integer, intent(out) :: ncid
+    integer, optional, intent(in) :: cache_size, cache_nelems
+    real, optional, intent(in) :: cache_preemption
+    integer :: size_in, nelems_in, preemption_in
+    integer :: size_out, nelems_out, preemption_out, ret
     integer :: nf90_open_par
   
+    ! If the user specified chuck cache parameters, use them. But user
+    ! may have specified one, two, or three settings. Leave the others
+    ! unchanged.
+    if (present(cache_size) .or. present(cache_nelems) .or. &
+         present(cache_preemption)) then
+       ret = nf_get_chunk_cache(size_in, nelems_in, preemption_in)
+       if (ret .ne. nf90_noerr) then
+          nf90_open_par = ret
+          return
+       end if
+       if (present(cache_size)) then
+          size_out = cache_size
+       else
+          size_out = size_in
+       end if
+       if (present(cache_nelems)) then
+          nelems_out = cache_nelems
+       else
+          nelems_out = nelems_in
+       end if
+       if (present(cache_preemption)) then
+          preemption_out = cache_preemption
+       else
+          preemption_out = preemption_in
+       end if
+       nf90_open_par = nf_set_chunk_cache(size_out, nelems_out, preemption_out)
+       if (nf90_open_par .ne. nf90_noerr) return
+    end if 
+
     nf90_open_par = nf_open_par(path, cmode, comm, info, ncid)
   end function nf90_open_par
   ! -----------
