@@ -295,6 +295,7 @@ extern "C" {
 #define NC_EDATADDS	(-73)   /* Malformed or inaccessible DATADDS */
 #define NC_EDAPURL	(-74)   /* Malformed DAP URL */
 #define NC_EDAPCONSTRAINT (-75)   /* Malformed DAP Constraint*/
+#define NC_ETRANSLATION (-76)   /* Untranslatable construct */
 
 /* The following was added in support of netcdf-4. Make all netcdf-4
    error codes < -100 so that errors can be added to netcdf-3 if
@@ -357,20 +358,17 @@ extern "C" {
 #   define MSC_EXTRA __declspec(dllimport)
 #  endif
 #include <io.h>
-#ifndef uint
-   typedef unsigned int uint;
-#endif
 /*#define lseek _lseeki64
   #define off_t __int64*/
 #else
 #define MSC_EXTRA
 #endif	/* defined(DLL_NETCDF) */
 
-# define EXTERNL extern MSC_EXTRA
+# define EXTERNL MSC_EXTRA extern
 
 #if defined(DLL_NETCDF) /* define when library is a DLL */
-MSC_EXTRA int ncerr;
-MSC_EXTRA int ncopts;
+EXTERNL int ncerr;
+EXTERNL int ncopts;
 #endif
 
 EXTERNL const char *
