@@ -2,25 +2,24 @@
  *	Copyright 1996, University Corporation for Atmospheric Research
  *      See netcdf/COPYRIGHT file for copying and redistribution conditions.
  */
-/* $Id: nc.c,v 2.159 2010/04/11 04:15:39 dmh Exp $ */
 
-#include "nc.h"
-#include "rename.h"
-#include "rnd.h"
+#include <config.h>
 #include <stdlib.h>
 #include <string.h>
 #include <assert.h>
-#include "ncx.h"
 #if defined(LOCKNUMREC) /* && _CRAYMPP */
 #  include <mpp/shmem.h>
 #  include <intrinsics.h>
 #endif
-#ifdef HAVE_UNISTD
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 
-/* list of open netcdf's */
-static NC *NClist = NULL;
+#include "nc.h"
+#include "ncdispatch.h"
+#include "nc3dispatch.h"
+#include "rnd.h"
+#include "ncx.h"
 
 /* This is the default create format for nc_create and nc__create. */
 int default_create_format = NC_FORMAT_CLASSIC;
@@ -31,64 +30,15 @@ int default_create_format = NC_FORMAT_CLASSIC;
 #define VER_64BIT_OFFSET 2
 #define VER_HDF5 3
 
-static void
-add_to_NCList(NC *ncp)
-{
-	assert(ncp != NULL);
-
-	ncp->prev = NULL;
-	if(NClist != NULL)
-		NClist->prev = ncp;
-	ncp->next = NClist;
-	NClist = ncp;
-}
-
-static void
-del_from_NCList(NC *ncp)
-{
-	assert(ncp != NULL);
-
-	if(NClist == ncp)
-	{
-		assert(ncp->prev == NULL);
-		NClist = ncp->next;
-	}
-	else
-	{
-		assert(ncp->prev != NULL);
-		ncp->prev->next = ncp->next;
-	}
-
-	if(ncp->next != NULL)
-		ncp->next->prev = ncp->prev;
-
-	ncp->next = NULL;
-	ncp->prev = NULL;
-}
-
-
 int
 NC_check_id(int ncid, NC **ncpp)
 {
-	NC *ncp;
-
-	if(ncid >= 0)
-	{
-		for(ncp = NClist; ncp != NULL; ncp = ncp->next)
-		{
-			if(ncp->nciop->fd == ncid)
-			{
-				*ncpp = ncp;
-				return NC_NOERR; /* normal return */
-			}
-		}
-	}
-
-	/* else, not found */
-	return NC_EBADID;
+    NC* nc = find_in_NCList(ncid);
+    if(nc == NULL) return NC_EBADID;
+    if(ncpp) *ncpp = nc;
+    return NC_NOERR;
 }
 
-
 static void
 free_NC(NC *ncp)
 {
@@ -97,6 +47,8 @@ free_NC(NC *ncp)
 	free_NC_dimarrayV(&ncp->dims);
 	free_NC_attrarrayV(&ncp->attrs);
 	free_NC_vararrayV(&ncp->vars);
+	if (ncp->path)
+	   free(ncp->path);
 #if _CRAYMPP && defined(LOCKNUMREC)
 	shfree(ncp);
 #else
@@ -104,43 +56,26 @@ free_NC(NC *ncp)
 #endif /* _CRAYMPP && LOCKNUMREC */
 }
 
-
 static NC *
-new_NC(const size_t *chunkp)
+new_NC(const size_t *chunkp, NC_Dispatch* dispatch)
 {
 	NC *ncp;
-
-#if _CRAYMPP && defined(LOCKNUMREC)
-	ncp = (NC *) shmalloc(sizeof(NC));
-#else
-	ncp = (NC *) malloc(sizeof(NC));
-#endif /* _CRAYMPP && LOCKNUMREC */
-	if(ncp == NULL)
-		return NULL;
-	(void) memset(ncp, 0, sizeof(NC));
-
+	int stat = dispatch->new_nc(&ncp);
+	if(stat) return NULL;
 	ncp->xsz = MIN_NC_XSZ;
 	assert(ncp->xsz == ncx_len_NC(ncp,0));
-	
-	ncp->chunk = chunkp != NULL ? *chunkp : NC_SIZEHINT_DEFAULT;
-
+        ncp->chunk = chunkp != NULL ? *chunkp : NC_SIZEHINT_DEFAULT;
 	return ncp;
 }
 
-
 static NC *
 dup_NC(const NC *ref)
 {
 	NC *ncp;
-
-#if _CRAYMPP && defined(LOCKNUMREC)
-	ncp = (NC *) shmalloc(sizeof(NC));
-#else
-	ncp = (NC *) malloc(sizeof(NC));
-#endif /* _CRAYMPP && LOCKNUMREC */
+	int stat = ref->dispatch->new_nc(&ncp);
+	if(stat) return NULL;
 	if(ncp == NULL)
 		return NULL;
-	(void) memset(ncp, 0, sizeof(NC));
 
 	if(dup_NC_dimarrayV(&ncp->dims, &ref->dims) != NC_NOERR)
 		goto err;
@@ -871,12 +806,11 @@ NC_init_pe(NC *ncp, int basepe) {
  * Compute the expected size of the file.
  */
 int
-NC_calcsize(NC *ncp, off_t *calcsizep)
+NC_calcsize(const NC *ncp, off_t *calcsizep)
 {
 	NC_var **vpp = (NC_var **)ncp->vars.value;
 	NC_var *const *const end = &vpp[ncp->vars.nelems];
 	NC_var *last_fix = NULL;	/* last "non-record" var */
-	int status;
 	int numrecvars = 0;	/* number of record variables */
 
 	if(ncp->vars.nelems == 0) { /* no non-record variables and 
@@ -886,9 +820,6 @@ NC_calcsize(NC *ncp, off_t *calcsizep)
 	}
 
 	for( /*NADA*/; vpp < end; vpp++) {
-	    status = NC_var_shape(*vpp, &ncp->dims);
-	    if(status != NC_NOERR)
-		return status;
 	    if(IS_RECVAR(*vpp)) {
 		numrecvars++;
 	    } else {
@@ -897,8 +828,17 @@ NC_calcsize(NC *ncp, off_t *calcsizep)
 	}
 
 	if(numrecvars == 0) {
+	    off_t varsize;
 	    assert(last_fix != NULL);
-	    *calcsizep = last_fix->begin + last_fix->len;
+	    varsize = last_fix->len;
+	    if(last_fix->len == X_UINT_MAX) { /* huge last fixed var */
+		int i;
+		varsize = 1;
+		    for(i = 0; i < last_fix->ndims; i++ ) {
+			varsize *= last_fix->shape[i];
+		    }
+	    }
+	    *calcsizep = last_fix->begin + varsize;
 	    /*last_var = last_fix;*/
 	} else {       /* we have at least one record variable */
 	    *calcsizep = ncp->begin_rec + ncp->numrecs * ncp->recsize;
@@ -909,17 +849,34 @@ NC_calcsize(NC *ncp, off_t *calcsizep)
 
 /* Public */
 
-int
-nc__create(const char * path, int ioflags, size_t initialsz,
-	size_t *chunksizehintp, int *ncid_ptr)
+int NC3_new_nc(NC** ncpp)
 {
-	return nc__create_mp(path, ioflags, initialsz, 0,
-		chunksizehintp, ncid_ptr);
+	NC *ncp;
+
+#if _CRAYMPP && defined(LOCKNUMREC)
+	ncp = (NC *) shmalloc(sizeof(NC));
+#else
+	ncp = (NC *) malloc(sizeof(NC));
+#endif /* _CRAYMPP && LOCKNUMREC */
+	if(ncp == NULL)
+		return NC_ENOMEM;
+	(void) memset(ncp, 0, sizeof(NC));
+
+	ncp->xsz = MIN_NC_XSZ;
+	assert(ncp->xsz == ncx_len_NC(ncp,0));
+	
+        if(ncpp) *ncpp = ncp;
+        return NC_NOERR;
+
 }
 
+/* WARNING: SIGNATURE CHANGE */
 int
-RENAME(_create_mp)(const char * path, int ioflags, size_t initialsz, int basepe,
-	size_t *chunksizehintp, int *ncid_ptr)
+NC3_create(const char *path, int ioflags,
+		size_t initialsz, int basepe,
+		size_t *chunksizehintp,
+		int use_parallel, void* parameters,
+                NC_Dispatch* dispatch, NC** ncpp)
 {
 	NC *ncp;
 	int status;
@@ -930,7 +887,7 @@ RENAME(_create_mp)(const char * path, int ioflags, size_t initialsz, int basepe,
 	fSet(ioflags, NC_SHARE);
 #endif
 
-	ncp = new_NC(chunksizehintp);
+	ncp = new_NC(chunksizehintp,dispatch);
 	if(ncp == NULL)
 		return NC_ENOMEM;
 
@@ -995,7 +952,11 @@ RENAME(_create_mp)(const char * path, int ioflags, size_t initialsz, int basepe,
 
 	if(chunksizehintp != NULL)
 		*chunksizehintp = ncp->chunk;
-	*ncid_ptr = ncp->nciop->fd;
+
+	ncp->int_ncid = ncp->nciop->fd;
+
+	if(ncpp) *ncpp = ncp;	
+
 	return NC_NOERR;
 
 unwind_ioc:
@@ -1033,22 +994,10 @@ nc_set_default_format(int format, int *old_formatp)
 }
 
 int
-nc_create(const char * path, int ioflags, int *ncid_ptr)
-{
-	return nc__create(path, ioflags, 0, NULL, ncid_ptr);
-}
-
-int
-nc__open(const char * path, int ioflags,
-	size_t *chunksizehintp, int *ncid_ptr)
-{
-	return nc__open_mp(path, ioflags, 0,
-		chunksizehintp, ncid_ptr);
-}
-
-int
-RENAME(_open_mp)(const char * path, int ioflags, int basepe,
-	size_t *chunksizehintp, int *ncid_ptr)
+NC3_open(const char * path, int ioflags,
+               int basepe, size_t *chunksizehintp,
+	       int use_parallel,void* parameters,
+               NC_Dispatch* dispatch, NC** ncpp)
 {
 	NC *ncp;
 	int status;
@@ -1057,7 +1006,7 @@ RENAME(_open_mp)(const char * path, int ioflags, int basepe,
 	fSet(ioflags, NC_SHARE);
 #endif
 
-	ncp = new_NC(chunksizehintp);
+	ncp = new_NC(chunksizehintp,dispatch);
 	if(ncp == NULL)
 		return NC_ENOMEM;
 
@@ -1101,7 +1050,12 @@ RENAME(_open_mp)(const char * path, int ioflags, int basepe,
 
 	if(chunksizehintp != NULL)
 		*chunksizehintp = ncp->chunk;
-	*ncid_ptr = ncp->nciop->fd;
+
+
+	ncp->int_ncid = ncp->nciop->fd;
+
+	if(ncpp) *ncpp = ncp;
+
 	return NC_NOERR;
 
 unwind_ioc:
@@ -1114,14 +1068,7 @@ unwind_alloc:
 }
 
 int
-nc_open(const char * path, int ioflags, int *ncid_ptr)
-{
-	return nc__open(path, ioflags, NULL, ncid_ptr);
-}
-
-
-int
-RENAME(_enddef)(int ncid,
+NC3__enddef(int ncid,
 	size_t h_minfree, size_t v_align,
 	size_t v_minfree, size_t r_align)
 {
@@ -1138,26 +1085,9 @@ RENAME(_enddef)(int ncid,
 	return (NC_endef(ncp, h_minfree, v_align, v_minfree, r_align));
 }
 
-int
-RENAME(enddef)(int ncid)
-{
-	int status;
-	NC *ncp;
-
-	status = NC_check_id(ncid, &ncp); 
-	if(status != NC_NOERR)
-		return status;
-
-	if(!NC_indef(ncp))
-		return(NC_ENOTINDEFINE);
-
-	/* return(NC_endef(ncp, 0, 4096, 0, 4096)); */
-	return (NC_endef(ncp, 0, 1, 0, 1));
-}
-
 
 int
-RENAME(close)(int ncid)
+NC3_close(int ncid)
 {
 	int status = NC_NOERR;
 	NC *ncp; 
@@ -1213,70 +1143,13 @@ RENAME(close)(int ncid)
 	return status;
 }
 
-
-int
-nc_delete(const char * path)
-{
-	return nc_delete_mp(path, 0);
-}
-
-int
-nc_delete_mp(const char * path, int basepe)
-{
-	NC *ncp;
-	int status;
-	size_t chunk = 512;
-
-	ncp = new_NC(&chunk);
-	if(ncp == NULL)
-		return NC_ENOMEM;
-	
-#if defined(LOCKNUMREC) /* && _CRAYMPP */
-	if (status = NC_init_pe(ncp, basepe)) {
-		return status;
-	}
-#else
-	/*
-	 * !_CRAYMPP, only pe 0 is valid
-	 */
-	if(basepe != 0)
-		return NC_EINVAL;
-#endif
-	status = ncio_open(path, NC_NOWRITE,
-		0, 0, &ncp->chunk,
-		&ncp->nciop, 0);
-	if(status)
-		goto unwind_alloc;
-
-	assert(ncp->flags == 0);
-
-	status = nc_get_NC(ncp);
-	if(status != NC_NOERR)
-	{
-		/* Not a netcdf file, don't delete */
-		/* ??? is this the right semantic? what if it was just too big? */
-		(void) ncio_close(ncp->nciop, 0);
-	}
-	else
-	{
-		/* ncio_close does the unlink */
-		status = ncio_close(ncp->nciop, 1); /* ncio_close does the unlink */
-	}
-
-	ncp->nciop = NULL;
-unwind_alloc:
-	free_NC(ncp);
-	return status;
-}
-
-
 /*
  * In data mode, same as ncclose.
  * In define mode, restore previous definition.
  * In create, remove the file.
  */
 int
-RENAME(abort)(int ncid)
+NC3_abort(int ncid)
 {
 	int status;
 	NC *ncp;
@@ -1317,7 +1190,7 @@ RENAME(abort)(int ncid)
 
 
 int
-RENAME(redef)(int ncid)
+NC3_redef(int ncid)
 {
 	int status;
 	NC *ncp;
@@ -1352,7 +1225,7 @@ RENAME(redef)(int ncid)
 
 
 int
-DISPNAME(inq)(int ncid,
+NC3_inq(int ncid,
 	int *ndimsp,
 	int *nvarsp,
 	int *nattsp,
@@ -1378,55 +1251,7 @@ DISPNAME(inq)(int ncid,
 }
 
 int 
-nc_inq_ndims(int ncid, int *ndimsp)
-{
-	int status;
-	NC *ncp;
-
-	status = NC_check_id(ncid, &ncp); 
-	if(status != NC_NOERR)
-		return status;
-
-	if(ndimsp != NULL)
-		*ndimsp = (int) ncp->dims.nelems;
-
-	return NC_NOERR;
-}
-
-int 
-nc_inq_nvars(int ncid, int *nvarsp)
-{
-	int status;
-	NC *ncp;
-
-	status = NC_check_id(ncid, &ncp); 
-	if(status != NC_NOERR)
-		return status;
-
-	if(nvarsp != NULL)
-		*nvarsp = (int) ncp->vars.nelems;
-
-	return NC_NOERR;
-}
-
-int 
-nc_inq_natts(int ncid, int *nattsp)
-{
-	int status;
-	NC *ncp;
-
-	status = NC_check_id(ncid, &ncp); 
-	if(status != NC_NOERR)
-		return status;
-
-	if(nattsp != NULL)
-		*nattsp = (int) ncp->attrs.nelems;
-
-	return NC_NOERR;
-}
-
-int 
-nc_inq_unlimdim(int ncid, int *xtendimp)
+NC3_inq_unlimdim(int ncid, int *xtendimp)
 {
 	int status;
 	NC *ncp;
@@ -1441,9 +1266,8 @@ nc_inq_unlimdim(int ncid, int *xtendimp)
 	return NC_NOERR;
 }
 
-
 int
-RENAME(sync)(int ncid)
+NC3_sync(int ncid)
 {
 	int status;
 	NC *ncp;
@@ -1484,7 +1308,7 @@ RENAME(sync)(int ncid)
 
 
 int
-DISPNAME(set_fill)(int ncid,
+NC3_set_fill(int ncid,
 	int fillmode, int *old_mode_ptr)
 {
 	int status;
@@ -1532,14 +1356,16 @@ DISPNAME(set_fill)(int ncid,
 #ifdef LOCKNUMREC
 
 /* create function versions of the NC_*_numrecs macros */
-size_t NC_get_numrecs(const NC *ncp) {
+size_t
+NC_get_numrecs(const NC *ncp) {
 	shmem_t numrec;
 	shmem_short_get(&numrec, (shmem_t *) ncp->lock + LOCKNUMREC_VALUE, 1,
 		ncp->lock[LOCKNUMREC_BASEPE]);
 	return (size_t) numrec;
 }
 
-void NC_set_numrecs(NC *ncp, size_t nrecs) {
+void
+NC_set_numrecs(NC *ncp, size_t nrecs) {
 	shmem_t numrec = (shmem_t) nrecs;
 	/* update local value too */
 	ncp->lock[LOCKNUMREC_VALUE] = (ushmem_t) numrec;
@@ -1559,7 +1385,7 @@ void NC_increase_numrecs(NC *ncp, size_t nrecs) {
 /* everyone in communicator group will be executing this */
 /*ARGSUSED*/
 int
-DISPNAME(set_base_pe)(int ncid, int pe)
+NC3_set_base_pe(int ncid, int pe)
 {
 #if _CRAYMPP && defined(LOCKNUMREC)
 	int status;
@@ -1600,7 +1426,7 @@ DISPNAME(set_base_pe)(int ncid, int pe)
 
 /*ARGSUSED*/
 int
-DISPNAME(inq_base_pe)(int ncid, int *pe)
+NC3_inq_base_pe(int ncid, int *pe)
 {
 #if _CRAYMPP && defined(LOCKNUMREC)
 	int status;
@@ -1621,7 +1447,7 @@ DISPNAME(inq_base_pe)(int ncid, int *pe)
 }
 
 int
-DISPNAME(inq_format)(int ncid, int *formatp)
+NC3_inq_format(int ncid, int *formatp)
 {
 	int status;
 	NC *ncp;
@@ -1637,73 +1463,6 @@ DISPNAME(inq_format)(int ncid, int *formatp)
 	return NC_NOERR;
 }
 
-
-#ifdef USE_DAP
-/*
-Following routines need to be externally accessible by drno code
-1. add_to_NCList
-2. del_from_NCList
-3. free_NC
-4. new_NC
-Also need to be able to set the size of unlimited.
-=> extra function
-*/
-
-void
-drno_add_to_NCList(NC *ncp)
-{
-    add_to_NCList(ncp);
-}
-
-void
-drno_del_from_NCList(NC *ncp)
-{
-    del_from_NCList(ncp);
-}
-
-void
-drno_free_NC(NC *ncp)
-{
-    free_NC(ncp);
-}
-
-NC *
-drno_new_NC(const size_t *chunkp)
-{
-    return new_NC(chunkp);
-}
-
-void
-drno_set_numrecs(NC* ncp, size_t size)
-{
-    NC_set_numrecs(ncp,size);    
-}
-
-size_t
-drno_get_numrecs(NC* ncp)
-{
-    return NC_get_numrecs(ncp);
-}
-
-int
-drno_ncio_open(NC* ncp, const char* path, int mode)
-{
-    int ncstat;
-    ncio* nciop = NULL;
-    size_t sizehint = NC_SIZEHINT_DEFAULT;
-    off_t igeto = 0;
-    size_t igetsz = 0;
-    void* ignore = (void*)17;
-    ncstat = ncio_open(path,mode,igeto,igetsz,&sizehint,&nciop,&ignore);
-    if(ncstat != NC_NOERR) nciop = NULL;
-    ncp->nciop = nciop;
-    return ncstat;
-}
-
-#endif
-
-#ifndef USE_NETCDF4
-
 /* The sizes of types may vary from platform to platform, but within
  * netCDF files, type sizes are fixed. */
 #define NC_BYTE_LEN 1
@@ -1717,7 +1476,7 @@ drno_ncio_open(NC* ncp, const char* path, int mode)
 /* This netCDF-4 function proved so popular that a netCDF-classic
  * version is provided. You're welcome. */
 int
-DISPNAME(inq_type)(int ncid, nc_type typeid, char *name, size_t *size)
+NC3_inq_type(int ncid, nc_type typeid, char *name, size_t *size)
 {
    int atomic_size[NUM_ATOMIC_TYPES] = {NC_BYTE_LEN, NC_CHAR_LEN, NC_SHORT_LEN, 
 					NC_INT_LEN, NC_FLOAT_LEN, NC_DOUBLE_LEN};
@@ -1738,4 +1497,59 @@ DISPNAME(inq_type)(int ncid, nc_type typeid, char *name, size_t *size)
    return NC_NOERR;
 }
 
-#endif /* USE_NETCDF4 */
+int
+nc_delete_mp(const char * path, int basepe)
+{
+	NC *ncp;
+	int status;
+	size_t chunk = 512;
+
+	status = NC3_new_nc(&ncp);
+        if(status) return status;
+        ncp->chunk = chunk;
+	
+#if defined(LOCKNUMREC) /* && _CRAYMPP */
+	if (status = NC_init_pe(ncp, basepe)) {
+		return status;
+	}
+#else
+	/*
+	 * !_CRAYMPP, only pe 0 is valid
+	 */
+	if(basepe != 0)
+		return NC_EINVAL;
+#endif
+	status = ncio_open(path, NC_NOWRITE,
+		0, 0, &ncp->chunk,
+		&ncp->nciop, 0);
+	if(status)
+		goto unwind_alloc;
+
+	assert(ncp->flags == 0);
+
+	status = nc_get_NC(ncp);
+	if(status != NC_NOERR)
+	{
+		/* Not a netcdf file, don't delete */
+		/* ??? is this the right semantic? what if it was just too big? */
+		(void) ncio_close(ncp->nciop, 0);
+	}
+	else
+	{
+		/* ncio_close does the unlink */
+		status = ncio_close(ncp->nciop, 1); /* ncio_close does the unlink */
+	}
+
+	ncp->nciop = NULL;
+unwind_alloc:
+	free_NC(ncp);
+	return status;
+}
+
+int
+nc_delete(const char * path)
+{
+	return nc_delete_mp(path, 0);
+}
+
+
