@@ -2,13 +2,16 @@
  *	Copyright 1996, University Corporation for Atmospheric Research
  *	See netcdf/COPYRIGHT file for copying and redistribution conditions.
  */
-/* "$Id: ncx.h,v 1.62 2008/09/23 13:58:44 ed Exp $" */
+/* "$Id: ncx.h,v 1.65 2010/05/26 18:11:08 dmh Exp $" */
 
 #ifndef _NCX_H_
 #define _NCX_H_
 
+#include "ncdispatch.h"
+
 /*
  * An external data representation interface.
+
  *
  * This started out as a general replacement for ONC XDR,
  * specifically, the xdrmem family of functions.
@@ -33,20 +36,14 @@
 typedef unsigned char uchar;
 #endif
 
+#define longlong long long
+
 #if defined(_CRAY) && !defined(_CRAYIEEE) && !defined(__crayx1)
 #define CRAYFLOAT 1 /* CRAY Floating point */
 #elif defined(_SX) && defined(_FLOAT2)	/* NEC SUPER-UX in CRAY mode */
 #define CRAYFLOAT 1 /* CRAY Floating point */
 #endif
 
-
-#if defined(DLL_NETCDF) /* define when library is a DLL */
-#include <io.h>
-#define lseek _lseeki64
-#define off_t __int64
-#define _OFF_T_DEFINED
-#endif	/* defined(DLL_NETCDF) */
-
 /*
  * The integer return code for the conversion routines
  * is 0 (ENOERR) when no error occured, or NC_ERANGE as appropriate
@@ -436,6 +433,12 @@ extern int
 ncx_getn_schar_float(const void **xpp, size_t nelems, float *ip);
 extern int
 ncx_getn_schar_double(const void **xpp, size_t nelems, double *ip);
+extern int
+ncx_getn_schar_uint(const void **xpp, size_t nelems, unsigned int *ip);
+extern int
+ncx_getn_schar_longlong(const void **xpp, size_t nelems, longlong *ip);
+extern int
+ncx_getn_schar_ulonglong(const void **xpp, size_t nelems, ulonglong *ip);
 
 extern int
 ncx_pad_getn_schar_schar(const void **xpp, size_t nelems, schar *ip);
@@ -451,6 +454,12 @@ extern int
 ncx_pad_getn_schar_float(const void **xpp, size_t nelems, float *ip);
 extern int
 ncx_pad_getn_schar_double(const void **xpp, size_t nelems, double *ip);
+extern int
+ncx_pad_getn_schar_uint(const void **xpp, size_t nelems, unsigned int *ip);
+extern int
+ncx_pad_getn_schar_longlong(const void **xpp, size_t nelems, longlong *ip);
+extern int
+ncx_pad_getn_schar_ulonglong(const void **xpp, size_t nelems, ulonglong *ip);
 
 extern int
 ncx_putn_schar_schar(void **xpp, size_t nelems, const schar *ip);
@@ -466,6 +475,12 @@ extern int
 ncx_putn_schar_float(void **xpp, size_t nelems, const float *ip);
 extern int
 ncx_putn_schar_double(void **xpp, size_t nelems, const double *ip);
+extern int
+ncx_putn_schar_uint(void **xpp, size_t nelems, const unsigned int *ip);
+extern int
+ncx_putn_schar_longlong(void **xpp, size_t nelems, const longlong *ip);
+extern int
+ncx_putn_schar_ulonglong(void **xpp, size_t nelems, const ulonglong *ip);
  
 extern int
 ncx_pad_putn_schar_schar(void **xpp, size_t nelems, const schar *ip);
@@ -481,6 +496,12 @@ extern int
 ncx_pad_putn_schar_float(void **xpp, size_t nelems, const float *ip);
 extern int
 ncx_pad_putn_schar_double(void **xpp, size_t nelems, const double *ip);
+extern int
+ncx_pad_putn_schar_uint(void **xpp, size_t nelems, const unsigned int *ip);
+extern int
+ncx_pad_putn_schar_longlong(void **xpp, size_t nelems, const longlong *ip);
+extern int
+ncx_pad_putn_schar_ulonglong(void **xpp, size_t nelems, const ulonglong *ip);
 
 
 extern int
@@ -497,6 +518,12 @@ extern int
 ncx_getn_short_float(const void **xpp, size_t nelems, float *ip);
 extern int
 ncx_getn_short_double(const void **xpp, size_t nelems, double *ip);
+extern int
+ncx_getn_short_uint(const void **xpp, size_t nelems, unsigned int *ip);
+extern int
+ncx_getn_short_longlong(const void **xpp, size_t nelems, longlong *ip);
+extern int
+ncx_getn_short_ulonglong(const void **xpp, size_t nelems, ulonglong *ip);
 
 extern int
 ncx_pad_getn_short_schar(const void **xpp, size_t nelems, schar *ip);
@@ -512,6 +539,12 @@ extern int
 ncx_pad_getn_short_float(const void **xpp, size_t nelems, float *ip);
 extern int
 ncx_pad_getn_short_double(const void **xpp, size_t nelems, double *ip);
+extern int
+ncx_pad_getn_short_uint(const void **xpp, size_t nelems, unsigned int *ip);
+extern int
+ncx_pad_getn_short_longlong(const void **xpp, size_t nelems, longlong *ip);
+extern int
+ncx_pad_getn_short_ulonglong(const void **xpp, size_t nelems, ulonglong *ip);
 
 extern int
 ncx_putn_short_schar(void **xpp, size_t nelems, const schar *ip);
@@ -527,6 +560,12 @@ extern int
 ncx_putn_short_float(void **xpp, size_t nelems, const float *ip);
 extern int
 ncx_putn_short_double(void **xpp, size_t nelems, const double *ip);
+extern int
+ncx_putn_short_uint(void **xpp, size_t nelems, const unsigned int *ip);
+extern int
+ncx_putn_short_longlong(void **xpp, size_t nelems, const longlong *ip);
+extern int
+ncx_putn_short_ulonglong(void **xpp, size_t nelems, const ulonglong *ip);
  
 extern int
 ncx_pad_putn_short_schar(void **xpp, size_t nelems, const schar *ip);
@@ -542,6 +581,12 @@ extern int
 ncx_pad_putn_short_float(void **xpp, size_t nelems, const float *ip);
 extern int
 ncx_pad_putn_short_double(void **xpp, size_t nelems, const double *ip);
+extern int
+ncx_pad_putn_short_uint(void **xpp, size_t nelems, const unsigned int *ip);
+extern int
+ncx_pad_putn_short_longlong(void **xpp, size_t nelems, const longlong *ip);
+extern int
+ncx_pad_putn_short_ulonglong(void **xpp, size_t nelems, const ulonglong *ip);
 
 
 extern int
@@ -558,6 +603,12 @@ extern int
 ncx_getn_int_float(const void **xpp, size_t nelems, float *ip);
 extern int
 ncx_getn_int_double(const void **xpp, size_t nelems, double *ip);
+extern int
+ncx_getn_int_uint(const void **xpp, size_t nelems, unsigned int *ip);
+extern int
+ncx_getn_int_longlong(const void **xpp, size_t nelems, longlong *ip);
+extern int
+ncx_getn_int_ulonglong(const void **xpp, size_t nelems, ulonglong *ip);
 
 extern int
 ncx_putn_int_schar(void **xpp, size_t nelems, const schar *ip);
@@ -573,6 +624,12 @@ extern int
 ncx_putn_int_float(void **xpp, size_t nelems, const float *ip);
 extern int
 ncx_putn_int_double(void **xpp, size_t nelems, const double *ip);
+extern int
+ncx_putn_int_uint(void **xpp, size_t nelems, const unsigned int *ip);
+extern int
+ncx_putn_int_longlong(void **xpp, size_t nelems, const longlong *ip);
+extern int
+ncx_putn_int_ulonglong(void **xpp, size_t nelems, const ulonglong *ip);
  
 
 extern int
@@ -589,6 +646,12 @@ extern int
 ncx_getn_float_float(const void **xpp, size_t nelems, float *ip);
 extern int
 ncx_getn_float_double(const void **xpp, size_t nelems, double *ip);
+extern int
+ncx_getn_float_uint(const void **xpp, size_t nelems, unsigned int *ip);
+extern int
+ncx_getn_float_longlong(const void **xpp, size_t nelems, longlong *ip);
+extern int
+ncx_getn_float_ulonglong(const void **xpp, size_t nelems, ulonglong *ip);
 
 extern int
 ncx_putn_float_schar(void **xpp, size_t nelems, const schar *ip);
@@ -604,6 +667,12 @@ extern int
 ncx_putn_float_float(void **xpp, size_t nelems, const float *ip);
 extern int
 ncx_putn_float_double(void **xpp, size_t nelems, const double *ip);
+extern int
+ncx_putn_float_uint(void **xpp, size_t nelems, const unsigned int *ip);
+extern int
+ncx_putn_float_longlong(void **xpp, size_t nelems, const longlong *ip);
+extern int
+ncx_putn_float_ulonglong(void **xpp, size_t nelems, const ulonglong *ip);
  
 
 extern int
@@ -620,6 +689,12 @@ extern int
 ncx_getn_double_float(const void **xpp, size_t nelems, float *ip);
 extern int
 ncx_getn_double_double(const void **xpp, size_t nelems, double *ip);
+extern int
+ncx_getn_double_uint(const void **xpp, size_t nelems, unsigned int *ip);
+extern int
+ncx_getn_double_longlong(const void **xpp, size_t nelems, longlong *ip);
+extern int
+ncx_getn_double_ulonglong(const void **xpp, size_t nelems, ulonglong *ip);
 
 extern int
 ncx_putn_double_schar(void **xpp, size_t nelems, const schar *ip);
@@ -635,6 +710,12 @@ extern int
 ncx_putn_double_float(void **xpp, size_t nelems, const float *ip);
 extern int
 ncx_putn_double_double(void **xpp, size_t nelems, const double *ip);
+extern int
+ncx_putn_double_uint(void **xpp, size_t nelems, const unsigned int *ip);
+extern int
+ncx_putn_double_longlong(void **xpp, size_t nelems, const longlong *ip);
+extern int
+ncx_putn_double_ulonglong(void **xpp, size_t nelems, const ulonglong *ip);
  
 
 /*
