@@ -2,7 +2,7 @@
  *	Copyright 1996, University Corporation for Atmospheric Research
  *	See netcdf/COPYRIGHT file for copying and redistribution conditions.
  */
-/* $Id: posixio.c,v 1.88 2010/03/24 14:53:23 russ Exp $ */
+/* $Id: posixio.c,v 1.89 2010/05/22 21:59:08 dmh Exp $ */
 
 #include <config.h>
 #include <assert.h>
@@ -423,8 +423,8 @@ px_get(ncio *const nciop, ncio_px *const pxp,
 	int status = ENOERR;
 
 	const off_t blkoffset = _RNDDOWN(offset, (off_t)pxp->blksz);
-	size_t diff = (size_t)(offset - blkoffset);
-	size_t blkextent = _RNDUP(diff + extent, pxp->blksz);
+	off_t diff = (size_t)(offset - blkoffset);
+	off_t blkextent = _RNDUP(diff + extent, pxp->blksz);
 	
 	assert(extent != 0);
 	assert(extent < X_INT_MAX); /* sanity check */
@@ -505,6 +505,22 @@ px_get(ncio *const nciop, ncio_px *const pxp,
 			/* copy upper half into lower half */
 			(void) memcpy(pxp->bf_base, middle, pxp->bf_cnt);
 		}
+		else		/* added to fix nofill bug */
+		{
+			assert(pxp->bf_extent == 2 * pxp->blksz);
+			/* still have to page out lower half, if modified */
+			if(fIsSet(pxp->bf_rflags, RGN_MODIFIED))
+			{
+				assert(pxp->bf_refcount <= 0);
+				status = px_pgout(nciop,
+					pxp->bf_offset,
+					pxp->blksz,
+					pxp->bf_base,
+					&pxp->pos);
+				if(status != ENOERR)
+					return status;
+			}
+		}
 		pxp->bf_offset = blkoffset;
 		/* pxp->bf_extent = pxp->blksz; */
 
@@ -1422,7 +1438,9 @@ ncio_new(const char *path, int ioflags)
 #ifndef NCIO_MINBLOCKSIZE
 #define NCIO_MINBLOCKSIZE 256
 #endif
+#ifndef NCIO_MAXBLOCKSIZE
 #define NCIO_MAXBLOCKSIZE 268435456 /* sanity check, about X_SIZE_T_MAX/8 */
+#endif
 
 #ifdef S_IRUSR
 #define NC_DEFAULT_CREAT_MODE \
@@ -1494,11 +1512,16 @@ ncio_create(const char *path, int ioflags,
 	}
 	*((int *)&nciop->fd) = fd; /* cast away const */
 
-	if(*sizehintp < NCIO_MINBLOCKSIZE || *sizehintp > NCIO_MAXBLOCKSIZE)
+	if(*sizehintp < NCIO_MINBLOCKSIZE)
 	{
 		/* Use default */
 		*sizehintp = blksize(fd);
 	}
+	else if(*sizehintp >= NCIO_MAXBLOCKSIZE)
+	{
+		/* Use maximum allowed value */
+		*sizehintp = NCIO_MAXBLOCKSIZE;
+	}
 	else
 	{
 		*sizehintp = M_RNDUP(*sizehintp);
@@ -1618,11 +1641,16 @@ ncio_open(const char *path,
 	}
 	*((int *)&nciop->fd) = fd; /* cast away const */
 
-	if(*sizehintp < NCIO_MINBLOCKSIZE || *sizehintp > NCIO_MAXBLOCKSIZE)
+	if(*sizehintp < NCIO_MINBLOCKSIZE)
 	{
 		/* Use default */
 		*sizehintp = blksize(fd);
 	}
+	else if(*sizehintp >= NCIO_MAXBLOCKSIZE)
+	{
+		/* Use maximum allowed value */
+		*sizehintp = NCIO_MAXBLOCKSIZE;
+	}
 	else
 	{
 		*sizehintp = M_RNDUP(*sizehintp);
