@@ -2,10 +2,10 @@
  *	Copyright 1996, University Corporation for Atmospheric Research
  *      See netcdf/COPYRIGHT file for copying and redistribution conditions.
  */
-/* $Id: v1hpg.c,v 1.69 2009/02/20 20:35:04 dmh Exp $ */
+/* $Id: v1hpg.c,v 1.70 2010/05/26 21:43:34 dmh Exp $ */
 
+#include "config.h"
 #include "nc.h"
-#include "rename.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -1083,7 +1083,6 @@ v1h_get_NC_vararray(v1hs *gsp, NC_vararray *ncap)
 /* End NC_var */
 /* Begin NC */
 
-
 /*
  * Recompute the shapes of all variables
  * Sets ncp->begin_var to start of first variable.
@@ -1160,7 +1159,6 @@ NC_computeshapes(NC *ncp)
 	return(ENOERR);
 }
 
-
 /* How much space in the header is required for the NC data structure? */
 size_t
 ncx_len_NC(const NC *ncp, size_t sizeof_off_t)
