@@ -6,7 +6,7 @@
    
   This program runs some extra tests.
 
-  $Id: tst_misc.c,v 1.5 2008/10/20 01:48:08 ed Exp $
+  $Id: tst_misc.c,v 1.6 2010/05/05 22:15:36 dmh Exp $
 */
 
 #include <config.h>
@@ -29,6 +29,10 @@ main(int argc, char **argv)
       FILE *file;
       int i;
 
+      /* Appease valgrind by initializing our data. */
+      for (i = 0; i < DATA_LEN; i++)
+	 dummy_data[i] = i;
+
       for (i = DATA_LEN; i >= 0; i--)
       {
 	 /* Create a small file which is not a netCDF file. */
