@@ -2,7 +2,6 @@
 
 # This shell runs some parallel I/O tests.
 
-mpd&
 set -e
 echo
 echo "Testing MPI parallel I/O without netCDF..."
@@ -19,7 +18,7 @@ mpiexec -n 1 ./tst_parallel4
 mpiexec -n 2 ./tst_parallel4
 mpiexec -n 4 ./tst_parallel4
 mpiexec -n 8 ./tst_parallel4
-mpiexec -n 16 ./tst_parallel4
+#mpiexec -n 16 ./tst_parallel4
 #mpiexec -n 32 ./tst_parallel4
 #mpiexec -n 64 ./tst_parallel4
 echo
