@@ -1,7 +1,7 @@
 /*********************************************************************
  *   Copyright 1993, University Corporation for Atmospheric Research
  *   See netcdf/README file for copying and redistribution conditions.
- *   $Header: /upc/share/CVS/netcdf-3/ncdump/dumplib.c,v 1.83 2009/10/20 04:51:05 dmh Exp $
+ *   $Header: /upc/share/CVS/netcdf-3/ncdump/dumplib.c,v 1.85 2010/05/05 22:15:39 dmh Exp $
  *********************************************************************/
 
 /*
@@ -24,7 +24,7 @@
 #include "dumplib.h"
 #include "isnan.h"
 #include "nctime.h"
-
+#include "utils.h"
 static float float_eps;
 static double double_eps;
 
@@ -109,37 +109,6 @@ char float_att_fmt[] = "%#.NNgf";
 char float_attx_fmt[] = "%#.NNg";
 char double_att_fmt[] = "%#.NNg";
 
-/*
- * Print error message to stderr and exit
- */
-void
-error(const char *fmt, ...)
-{
-    va_list args ;
-
-    (void) fprintf(stderr,"%s: ", progname);
-    va_start(args, fmt) ;
-    (void) vfprintf(stderr,fmt,args) ;
-    va_end(args) ;
-
-    (void) fprintf(stderr, "\n") ;
-    (void) fflush(stderr);	/* to ensure log files are current */
-    exit(EXIT_FAILURE);
-}
-
-void *
-emalloc (			/* check return from malloc */
-	size_t size)
-{
-    void   *p;
-
-    p = (void *) malloc (size==0 ? 1 : size); /* don't malloc(0) */
-    if (p == 0) {
-	error ("out of memory\n");
-    }
-    return p;
-}
-
 #ifndef HAVE_STRLCAT
 /*	$OpenBSD: strlcat.c,v 1.12 2005/03/30 20:13:52 otto Exp $	*/
 
@@ -533,12 +502,12 @@ prim_type_name(nc_type type)
     }
 }
 
-static int number_of_types = 0;
+static int max_type = 0;
 static nctype_t **nctypes = 0;	/* holds all types in a netCDF dataset */
 
 
-/* return number of user-defined types in a group and all its subgroups */
 #ifdef USE_NETCDF4
+/* return number of user-defined types in a group and all its subgroups */
 static int
 count_udtypes(int ncid) {
     int ntypes = 0;
@@ -553,7 +522,7 @@ count_udtypes(int ncid) {
 	/* Get number of types in this group */
 	NC_CHECK( nc_inq_typeids(ncid, &ntypes, NULL) ) ;
 	NC_CHECK( nc_inq_grps(ncid, &numgrps, NULL) ) ;
-	ncids = (int *) emalloc(sizeof(int) * numgrps);
+	ncids = (int *) emalloc(sizeof(int) * (numgrps + 1));
 	NC_CHECK( nc_inq_grps(ncid, NULL, ncids) ) ;
 	/* Add number of types in each subgroup, if any */
 	for (i=0; i < numgrps; i++) {
@@ -563,18 +532,22 @@ count_udtypes(int ncid) {
     }
     return ntypes;
 }
-#endif	/* USE_NETCDF4 */
+#endif /*USE_NETCDF4*/
 
+/* This routine really is intended to return the max typeid */
 static int
-count_types(int ncid) {
-    int numtypes = 6;
+max_typeid(int ncid) {
+    int maxtypes = NC_DOUBLE; /*ignore NC_NAT?*/
 #ifdef USE_NETCDF4
-    numtypes += 6; 		/* extra netCDF-4 primitive types */
-    numtypes += 4;		/* user-defined classes */
-    numtypes += count_udtypes(ncid);
-#endif	/* USE_NETCDF4 */
-    number_of_types = numtypes;
-    return numtypes;
+    int nuser = 0;
+    maxtypes = NC_STRING; /* extra netCDF-4 primitive types */
+    maxtypes += 4;		/* user-defined classes */
+    nuser = count_udtypes(ncid);
+    if(nuser > 0) 
+	maxtypes = NC_FIRSTUSERTYPEID + (nuser - 1);
+#endif
+    max_type = maxtypes;
+    return maxtypes;
 }
 
 void typeadd(nctype_t *typep) {
@@ -584,7 +557,7 @@ void typeadd(nctype_t *typep) {
 /* From type id, get full type info */
 nctype_t *
 get_typeinfo ( int typeid ) {
-    if(typeid < 0 || typeid > number_of_types)
+    if(typeid < 0 || typeid > max_type)
 	error("ncdump: %d is an invalid type id", typeid);
     return nctypes[typeid];
 }
@@ -1005,7 +978,7 @@ ncopaque_val_as_hex(size_t size, char *sout, const void *valp) {
     char *prefix = "0X";
     int prelen = strlen(prefix);
 
-    snprintf(sp, prelen + 1, prefix);
+    snprintf(sp, prelen + 1, "%s", prefix);
     sp += prelen;
     for(i = 0; i < size; i++) {
 	int res;
@@ -1637,11 +1610,11 @@ init_types(int ncid) {
 #ifdef USE_NETCDF4
     int ntypes;
 #endif
-    if (number_of_types == 0) {	/* if called for first time */
-	int numtypes = count_types(ncid);
+    if (max_type == 0) {	/* if called for first time */
+	int maxtype = max_typeid(ncid);
 	int i;
-	nctypes = (nctype_t **) emalloc((numtypes + 1) * sizeof(nctype_t *));
-	for(i=0; i < numtypes; i++)
+	nctypes = (nctype_t **) emalloc((maxtype + 2) * sizeof(nctype_t *));
+	for(i=0; i < maxtype+1; i++)
 	    nctypes[i] = NULL;	/* so can later skip over unused type slots */
 	init_prim_types(ncid);
     }
@@ -1652,7 +1625,7 @@ init_types(int ncid) {
    if (ntypes)
    {
       int t;
-      int *typeids = emalloc(ntypes * sizeof(int));
+      int *typeids = emalloc((ntypes + 1) * sizeof(int));
       NC_CHECK( nc_inq_typeids(ncid, NULL, typeids) );
       for (t = 0; t < ntypes; t++) {
 	  nctype_t *tinfo;	/* details about the type */
@@ -1687,15 +1660,15 @@ init_types(int ncid) {
 	  case NC_COMPOUND:
 	      tinfo->val_equals = (val_equals_func) nccomp_val_equals;
 	      tinfo->typ_tostring = (typ_tostring_func) nccomp_typ_tostring;
-	      tinfo->fids = (nc_type *) emalloc(tinfo->nfields 
+	      tinfo->fids = (nc_type *) emalloc((tinfo->nfields + 1)
 						  * sizeof(nc_type));
-	      tinfo->offsets = (size_t *) emalloc(tinfo->nfields 
+	      tinfo->offsets = (size_t *) emalloc((tinfo->nfields + 1)
 						  * sizeof(size_t));
-	      tinfo->ranks = (int *) emalloc(tinfo->nfields 
+	      tinfo->ranks = (int *) emalloc((tinfo->nfields + 1)
 					     * sizeof(int));
-	      tinfo->sides = (int **) emalloc(tinfo->nfields 
+	      tinfo->sides = (int **) emalloc((tinfo->nfields + 1)
 						 * sizeof(int *));
-	      tinfo->nvals = (int *) emalloc(tinfo->nfields 
+	      tinfo->nvals = (int *) emalloc((tinfo->nfields + 1)
 					     * sizeof(int));
 	      for (fidx = 0; fidx < tinfo->nfields; fidx++) {
 		  size_t offset;
@@ -1773,17 +1746,39 @@ init_types(int ncid) {
 int
 iscoordvar(int ncid, int varid)
 {
-    int ndims;
+    int ndims, ndims1;
     int dimid;
-    ncdim_t *dims;
+    int* dimids = 0;
+    ncdim_t *dims = 0;
+    int include_parents = 1;
     int is_coord = 0;		/* true if variable is a coordinate variable */
     char varname[NC_MAX_NAME];
     int varndims;
 
-    NC_CHECK( nc_inq_ndims(ncid, &ndims) );
-    dims = (ncdim_t *) emalloc((ndims + 1) * sizeof(ncdim_t));
+    do {	  /* be safe in case someone is currently adding
+		   * dimensions */
+	NC_CHECK( nc_inq_ndims(ncid, &ndims) );
+	if (dims)
+	    free(dims);
+	dims = (ncdim_t *) emalloc((ndims + 1) * sizeof(ncdim_t));
+	if (dimids)
+	    free(dimids);
+	dimids = (int *) emalloc((ndims + 1) * sizeof(int));
+#ifdef USE_NETCDF4
+	NC_CHECK( nc_inq_dimids(ncid, &ndims1, dimids, include_parents ) );
+#else
+	{
+	    int i;
+	    for(i = 0; i < ndims; i++) {
+		dimids[i] = i;	/* for netCDF-3, dimids are 0, 1, ..., ndims-1 */
+	    }
+	    NC_CHECK( nc_inq_ndims(ncid, &ndims1) );
+	}
+#endif	/* USE_NETCDF4 */
+    } while (ndims != ndims1);
+
     for (dimid = 0; dimid < ndims; dimid++) {
-	NC_CHECK( nc_inq_dimname(ncid, dimid, dims[dimid].name) );
+	NC_CHECK( nc_inq_dimname(ncid, dimids[dimid], dims[dimid].name) );
     }
     NC_CHECK( nc_inq_varname(ncid, varid, varname) );
     NC_CHECK( nc_inq_varndims(ncid, varid, &varndims) );
@@ -1794,7 +1789,10 @@ iscoordvar(int ncid, int varid)
 	    break;
 	}
     }
-    free(dims);
+    if(dims)
+	free(dims);
+    if(dimids)
+	free(dimids);
     return is_coord;
 }
 
@@ -1854,92 +1852,6 @@ is_user_defined_type(nc_type type) {
     return (typeinfop->class > 0);
 }
 
-/* 
- * Returns malloced name with chars special to CDL escaped.
- * Caller should free result when done with it.
- */
-char*
-escaped_name(const char* cp) {
-    char *ret;			/* string returned */
-    char *sp;
-    assert(cp != NULL);
-
-    /* For some reason, and on some machines (e.g. tweety)
-       utf8 characters such as \343 are considered control character. */
-/*    if(*cp && (isspace(*cp) | iscntrl(*cp)))*/
-    if((*cp >= 0x01 && *cp <= 0x20) || (*cp == 0x7f))
-    {
-	error("name begins with space or control-character: %c",*cp);
-    }
-
-    ret = emalloc(4*strlen(cp) + 1); /* max if every char escaped */
-    sp = ret;
-    *sp = 0;			    /* empty name OK */
-    /* Special case: leading number allowed, but we must escape it for CDL */
-    if((*cp >= '0' && *cp <= '9'))
-    {
-	*sp++ = '\\';
-    }
-    for (; *cp; cp++) {
-	if (isascii(*cp)) {
-	    if(iscntrl(*cp)) {	/* render control chars as two hex digits, \%xx */
-		snprintf(sp, 4,"\\%%%.2x", *cp);
-		sp += 4;
-	    } else {
-		switch (*cp) {
-		case ' ':
-		case '!':
-		case '"':
-		case '#':
-		case '$':
-		case '%':
-		case '&':
-		case '\'':
-		case '(':
-		case ')':
-		case '*':
-		case ',':
-		case ':':
-		case ';':
-		case '<':
-		case '=':
-		case '>':
-		case '?':
-		case '[':
-		case ']':
-		case '\\':
-		case '^':
-		case '`':
-		case '{':
-		case '|':
-		case '}':
-		case '~':
-		    *sp++ = '\\';
-		    *sp++ = *cp;
-		    break;
-		default:		/* includes '/' */
-		    *sp++ = *cp;
-		    break;
-		}
-	    }
-	} else { 		/* not ascii, assume just UTF-8 byte */
-	    *sp++ = *cp;
-	}
-    }
-    *sp = 0;
-    return ret;
-}
-
-
-/* 
- * Print name with escapes for special characters
- */
-void
-print_name(const char* name) {
-    char *ename = escaped_name(name);
-    fputs(ename, stdout);
-    free(ename);
-}
 
 /* 
  * Return name of type in user-allocated space, whether built-in
@@ -1981,7 +1893,7 @@ print_type_name(int locid, int typeid) {
     int stat;
 #endif
 
-    assert(typeid > 0 && typeid <= number_of_types);
+    assert(typeid > 0 && typeid <= max_type);
     ename = escaped_name(nctypes[typeid]->name);
 #ifdef USE_NETCDF4
     if(is_user_defined_type(typeid)) {
