@@ -1,6 +1,6 @@
 #!/bin/sh
 # This shell script runs the ncdump tests.
-# $Id: run_tests.sh,v 1.16 2008/04/23 16:31:27 ed Exp $
+# $Id: run_tests.sh,v 1.18 2010/05/19 13:43:39 ed Exp $
 
 set -e
 echo ""
@@ -19,7 +19,8 @@ echo "*** creating test1.nc from test1.cdl..."
 ../ncgen/ncgen -b test1.cdl
 echo "*** creating test2.cdl from test1.nc..."
 ./ncdump test1.nc > test2.cdl
-echo "*** checking that test1.cdl and test2.nc are the same..."
+echo "*** checking that test1.cdl and test2.cdl are the same..."
 diff -w test1.cdl test2.cdl
+
 echo "*** All tests of ncgen and ncdump using test0.cdl passed!"
 exit 0
