@@ -19,10 +19,19 @@ export srcdir
 export builddir
 
 KFLAG=1 ; export KFLAG
+echo "Performing diff tests: k=1"
 sh ${srcdir}/tst_ncgen4_diff.sh
+echo "Performing cycle tests: k=1"
 sh  ${srcdir}/tst_ncgen4_cycle.sh
 KFLAG=3 ; export KFLAG
+echo "Performing diff tests: k=3"
 sh  ${srcdir}/tst_ncgen4_diff.sh
+echo "Performing cycle tests: k=3"
+sh  ${srcdir}/tst_ncgen4_cycle.sh
+KFLAG=4 ; export KFLAG
+echo "Performing diff tests: k=4"
+sh  ${srcdir}/tst_ncgen4_diff.sh
+echo "Performing cycle tests: k=4"
 sh  ${srcdir}/tst_ncgen4_cycle.sh
 exit
 
