@@ -5,7 +5,11 @@
 ALLXFAIL="${XFAILTESTS} ${SPECIALTESTS}"
 
 if test "${MODE}" = 3 ; then
-TESTSET="${TESTS3}"
+  if test "${KFLAG}" = 4 ; then
+    TESTSET="${TESTS3} ${SPECIALTESTS3}"
+  else
+    TESTSET="${TESTS3}"
+  fi
 else
 TESTSET="${TESTS3} ${TESTS4} ${ALLXFAIL}"
 fi
@@ -17,8 +21,9 @@ for x in ${TESTSET} ; do
   test $verbose = 1 && echo "*** Testing: ${x}"
 	# determine if we need the specflag set
 	specflag=
+	headflag=
 	for s in ${SPECIALTESTS} ; do
-	if test "x${s}" = "x${x}" ; then specflag="-s"; fi
+	if test "x${s}" = "x${x}" ; then specflag="-s"; headflag="-h"; fi
 	done
 	# determine if this is an xfailtest
 	isxfail=
@@ -28,9 +33,14 @@ for x in ${TESTSET} ; do
   rm -f ${x}.nc ${x}.dmp
   ${builddir}/../ncgen/ncgen -k${KFLAG} -o ${x}.nc ${cdl}/${x}.cdl
   # dump .nc file
-  ${builddir}/../ncdump/ncdump ${specflag} ${x}.nc > ${x}.dmp
-  # compare with expected
-  if diff -w ${expected}/${x}.dmp ${x}.dmp ; then
+  ${builddir}/../ncdump/ncdump ${headflag} ${specflag} ${x}.nc > ${x}.dmp
+  # compare the expected (silently if XFAIL)
+  if test "x$isxfail" = "x1" -a "x$SHOWXFAILS" = "x" ; then
+    if diff -bw ${expected}/${x}.dmp ${x}.dmp >/dev/null 2>&1; then ok=1; else ok=0; fi
+  else
+    if diff -w ${expected}/${x}.dmp ${x}.dmp ; then ok=1; else ok=0; fi
+  fi
+  if test "x$ok" = "x1" ; then
     test $verbose = 1 && echo "*** SUCCEED: ${x}"
     passcount=`expr $passcount + 1`
   elif test "x${isxfail}" = "x1" ; then
@@ -45,7 +55,7 @@ cd ..
 
 totalcount=`expr $passcount + $failcount + $xfailcount`
 okcount=`expr $passcount + $xfailcount`
-
+set -x
 echo "*** PASSED: ${okcount}/${totalcount} ; ${xfailcount} expected failures ; ${failcount} unexpected failures"
 
 if test $failcount -gt 0 ; then
