@@ -1,7 +1,7 @@
 /*********************************************************************
  *   Copyright 1993, UCAR/Unidata
  *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
- *   $Header: /upc/share/CVS/netcdf-3/ncdump/vardata.c,v 1.47 2010/02/04 16:49:13 russ Exp $
+ *   $Header: /upc/share/CVS/netcdf-3/ncdump/vardata.c,v 1.48 2010/05/05 22:15:39 dmh Exp $
  *********************************************************************/
 
 #include <config.h>
@@ -14,6 +14,7 @@
 #include "dumplib.h"
 #include "indent.h"
 #include "vardata.h"
+#include "utils.h"
 
 /* maximum len of string needed for one value of a primitive type */
 #define MAX_OUTPUT_LEN 100
@@ -360,9 +361,9 @@ vardata(
      const fspec_t *fsp	        /* formatting specs */
      )
 {
-    size_t cor[NC_MAX_DIMS];	/* corner coordinates */
-    size_t edg[NC_MAX_DIMS];	/* edges of hypercube */
-    size_t add[NC_MAX_DIMS];	/* "odometer" increment to next "row"  */
+    size_t *cor;	     /* corner coordinates */
+    size_t *edg;	     /* edges of hypercube */
+    size_t *add;	     /* "odometer" increment to next "row"  */
     size_t gulp;
     void *vals;
 
@@ -373,8 +374,15 @@ vardata(
     size_t nrows;
     int vrank = vp->ndims;
 
+    cor = (size_t *) emalloc((1 + vrank) * sizeof(size_t));
+    edg = (size_t *) emalloc((1 + vrank) * sizeof(size_t));
+    add = (size_t *) emalloc((1 + vrank) * sizeof(size_t));
+
     nels = 1;
-    for (id = 0; id < vrank; id++) {
+    if(vrank == 0) { /*scalar*/
+	cor[0] = 0;
+	edg[0] = 1;
+    } for (id = 0; id < vrank; id++) {
 	cor[id] = 0;
 	edg[id] = 1;
 	nels *= vdims[id];	/* total number of values for variable */
@@ -483,6 +491,10 @@ vardata(
     }
 
     free(vals);
+    free(cor);
+    free(edg);
+    free(add);
+
     return 0;
 }
 
@@ -614,9 +626,9 @@ vardatax(
      const fspec_t *fsp	        /* formatting specs */
      )
 {
-    size_t cor[NC_MAX_DIMS];	/* corner coordinates */
-    size_t edg[NC_MAX_DIMS];	/* edges of hypercube */
-    size_t add[NC_MAX_DIMS];	/* "odometer" increment to next "row"  */
+    size_t *cor;	     /* corner coordinates */
+    size_t *edg;	     /* edges of hypercube */
+    size_t *add;	     /* "odometer" increment to next "row"  */
     size_t gulp;
     void *vals;
 
@@ -627,6 +639,10 @@ vardatax(
     size_t nrows;
     int vrank = vp->ndims;
 
+    cor = (size_t *) emalloc((vrank + 1) * sizeof(size_t));
+    edg = (size_t *) emalloc((vrank + 1) * sizeof(size_t));
+    add = (size_t *) emalloc((vrank + 1) * sizeof(size_t));
+
     nels = 1;
     for (id = 0; id < vrank; id++) {
 	cor[id] = 0;
@@ -692,5 +708,8 @@ vardatax(
     }
     printf(" </values>\n");
     free(vals);
+    free(cor);
+    free(edg);
+    free(add);
     return 0;
 }
