@@ -1,5 +1,13 @@
+/*********************************************************************
+ *   Copyright 2009, UCAR/Unidata
+ *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
+ *********************************************************************/
+/* $Id: cvt.c,v 1.2 2010/05/24 19:59:56 dmh Exp $ */
+/* $Header: /upc/share/CVS/netcdf-3/ncgen/cvt.c,v 1.2 2010/05/24 19:59:56 dmh Exp $ */
+
 #include        "includes.h"
 #include        "bytebuffer.h"
+#include	<math.h>
 
 static char stmp[256];
 
@@ -358,12 +366,11 @@ case CASE(NC_FLOAT,NC_INT64):
     tmp.int64v	 = (long long)src->value.floatv;
     break;
 case CASE(NC_FLOAT,NC_FLOAT):
-    tmp.floatv	= (float)src->value.floatv;
+    tmp.floatv = src->value.floatv;
     break;
 case CASE(NC_FLOAT,NC_DOUBLE):
-    tmp.doublev = (double)src->value.floatv;
+    tmp.doublev = (isnan(src->value.floatv)?NAN:(double)src->value.floatv);
     break;
-
 case CASE(NC_DOUBLE,NC_BYTE):
     tmp.uint8v	= (unsigned char)src->value.doublev;
     break;
@@ -389,7 +396,7 @@ case CASE(NC_DOUBLE,NC_INT64):
     tmp.int64v	 = (long long)src->value.doublev;
     break;
 case CASE(NC_DOUBLE,NC_FLOAT):
-    tmp.floatv	= (float)src->value.doublev;
+    tmp.floatv = (isnan(src->value.doublev)?NANF:(float)src->value.doublev);
     break;
 case CASE(NC_DOUBLE,NC_DOUBLE):
     tmp.doublev = (double)src->value.doublev;
