@@ -1,7 +1,7 @@
 /*********************************************************************
  *   Copyright 1993, UCAR/Unidata
  *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
- *   $Header: /upc/share/CVS/netcdf-3/ncgen/genf77.c,v 1.3 2010/04/04 19:39:46 dmh Exp $
+ *   $Header: /upc/share/CVS/netcdf-3/ncgen/genf77.c,v 1.4 2010/05/17 23:26:44 dmh Exp $
  *********************************************************************/
 
 #include "includes.h"
@@ -472,9 +472,7 @@ genf77_defineattr(Symbol* asym)
     Bytebuffer* code = NULL; /* capture other decls*/
 
     list = asym->data;
-    if(list == NULL) PANIC("empty attribute list");
-    len = list->length;
-    if(len == 0) PANIC("empty attribute list");
+    len = list==NULL?0:list->length;
 
     bbprintf0(stmt,"* define %s\n",asym->name);
     codedump(stmt);
@@ -510,7 +508,7 @@ genf77_defineattr(Symbol* asym)
 		(asym->att.var == NULL?"NF_GLOBAL"
 			              :f77varncid(asym->att.var)),
 		f77escapifyname(asym->name),
-	 	(len==0?1:len));
+	 	len);
 	codedump(stmt);
 	codedump(code);
 	codeline(")");
@@ -777,32 +775,33 @@ genf77_definevardata(Symbol* vsym)
     /* give the buffer a running start to be large enough*/
     bbSetalloc(code, nciterbuffersize);
 
-    src = datalist2src(vsym->data);
-    fillsrc = vsym->var.special._Fillvalue;
-
-    /* Handle special cases first*/
-    if(isscalar) {
-	f77data_basetype(vsym->typ.basetype,src,code,fillsrc);
-	commify(code);
-	genf77_write(vsym,code,NULL,1,0);
-    } else { /* Non-scalar*/
-	int index;
-        /* Create an iterator to generate blocks of data */
-        nc_get_iter(vsym,nciterbuffersize,&iter);
-        /* Fill in the local odometer instance */
-        odom = newodometer(&vsym->typ.dimset,NULL,NULL);
-        for(index=0;;index++) {
-	    nelems=nc_next_iter(&iter,odom->start,odom->count);
-	    if(nelems == 0) break;
-            if(chartype) {/* Handle character case separately */
-                gen_chararray(vsym,code,src,odom,0);
-    	    } else {
+    if(!isscalar && chartype) {
+        gen_chararray(vsym,code,fillsrc);
+        genf77_write(vsym,code,NULL,0,0);
+    } else { /* not character constant */
+        src = datalist2src(vsym->data);
+        fillsrc = vsym->var.special._Fillvalue;
+    
+        /* Handle special cases first*/
+        if(isscalar) {
+            f77data_basetype(vsym->typ.basetype,src,code,fillsrc);
+            commify(code);
+            genf77_write(vsym,code,NULL,1,0);
+        } else { /* Non-scalar*/
+            int index;
+            /* Create an iterator to generate blocks of data */
+            nc_get_iter(vsym,nciterbuffersize,&iter);
+            /* Fill in the local odometer instance */
+            odom = newodometer(&vsym->typ.dimset,NULL,NULL);
+            for(index=0;;index++) {
+                nelems=nc_next_iter(&iter,odom->start,odom->count);
+                if(nelems == 0) break;
                 f77data_array(vsym,code,src,odom,/*index=*/0,fillsrc);
-	    }
-	    genf77_write(vsym,code,odom,0,index);
-	}
+                genf77_write(vsym,code,odom,0,index);
+            }
+        }
+        odometerfree(odom);
     }
-    odometerfree(odom);
     bbFree(code);
 }
 
