@@ -1,7 +1,7 @@
 /*********************************************************************
  *   Copyright 1993, UCAR/Unidata
  *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
- *   $Header: /upc/share/CVS/netcdf-3/ncgen/genj.c,v 1.1 2010/04/04 19:39:46 dmh Exp $
+ *   $Header: /upc/share/CVS/netcdf-3/ncgen/genj.c,v 1.2 2010/05/17 23:26:44 dmh Exp $
  *********************************************************************/
 
 #include "includes.h"
@@ -259,9 +259,7 @@ genj_defineattribute(Symbol* asym)
     nc_type typecode = basetype->typ.typecode;
 
     list = asym->data;
-    if(list == NULL) PANIC("empty attribute list");
-    len = list->length;
-    if(len == 0) PANIC("empty attribute list");
+    len = list == NULL?0:list->length;
 
     codeprintf("%s/* attribute: %s */\n",indented(1),asym->name);
 
@@ -560,32 +558,33 @@ genj_definevardata(Symbol* vsym)
     /* give the buffer a running start to be large enough*/
     bbSetalloc(code, nciterbuffersize);
 
-    src = datalist2src(vsym->data);
-    fillsrc = vsym->var.special._Fillvalue;
-
-    /* Handle special cases first*/
-    if(isscalar) {
-	jdata_basetype(vsym->typ.basetype,src,code,fillsrc);
-	commify(code);
-	genj_write(vsym,code,NULL,1,0);
-     } else { /* Non-scalar*/
-	int index;
-        /* Create an iterator to generate blocks of data */
-        nc_get_iter(vsym,nciterbuffersize,&iter);
-        /* Fill in the local odometer instance */
-        odom = newodometer(&vsym->typ.dimset,NULL,NULL);
-        for(index=0;;index++) {
-	    nelems=nc_next_iter(&iter,odom->start,odom->count);
-	    if(nelems == 0) break;
-            if(chartype) {/* Handle character case separately */
-                gen_chararray(vsym,code,src,odom,0);
-    	    } else {
+    if(!isscalar && chartype) {
+        gen_chararray(vsym,code,fillsrc);
+        genj_write(vsym,code,NULL,0,0);
+    } else { /* not character constant */
+        src = datalist2src(vsym->data);
+        fillsrc = vsym->var.special._Fillvalue;
+    
+        /* Handle special cases first*/
+        if(isscalar) {
+            jdata_basetype(vsym->typ.basetype,src,code,fillsrc);
+            commify(code);
+            genj_write(vsym,code,NULL,1,0);
+         } else { /* Non-scalar*/
+            int index;
+            /* Create an iterator to generate blocks of data */
+            nc_get_iter(vsym,nciterbuffersize,&iter);
+            /* Fill in the local odometer instance */
+            odom = newodometer(&vsym->typ.dimset,NULL,NULL);
+            for(index=0;;index++) {
+                nelems=nc_next_iter(&iter,odom->start,odom->count);
+                if(nelems == 0) break;
                 jdata_array(vsym,code,src,odom,/*index=*/0,fillsrc);
-	    }
-	    genj_write(vsym,code,odom,0,index);
-	}
+                genj_write(vsym,code,odom,0,index);
+            }
+        }
+        odometerfree(odom);
     }
-    odometerfree(odom);
     bbFree(code);
 }
 
