@@ -1,9 +1,16 @@
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#else
-#include "config.h"
-#endif
+/*
+  This is part of ncgen, a utility which is part of netCDF. Copyright
+  2010, UCAR/Unidata. See COPYRIGHT file for copying and
+  redistribution conditions.
+ */
 
+/* $Id: includes.h,v 1.7 2010/05/25 18:57:00 dmh Exp $ */
+/* $Header: /upc/share/CVS/netcdf-3/ncgen/includes.h,v 1.7 2010/05/25 18:57:00 dmh Exp $ */
+
+#ifndef NCGEN_INCLUDES_H
+#define NCGEN_INCLUDES_H
+
+#include "config.h"
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -14,6 +21,10 @@
 #include <unistd.h>
 #endif
 
+#ifdef __SunOS
+#include <strings.h>
+#endif
+
 #ifdef __hpux
 #include <locale.h>
 #endif
@@ -40,3 +51,7 @@
 #else
 extern char* nulldup(const char*);
 #endif
+
+extern int specialconstants;
+
+#endif /* NCGEN_INCLUDES_H */
