@@ -1,13 +1,15 @@
 /*********************************************************************
  *   Copyright 1993, UCAR/Unidata
  *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
- *   $Header: /upc/share/CVS/netcdf-3/ncgen/main.c,v 1.26 2010/04/04 19:39:52 dmh Exp $
  *********************************************************************/
+/* $Id: main.c,v 1.33 2010/05/26 21:43:36 dmh Exp $ */
+/* $Header: /upc/share/CVS/netcdf-3/ncgen/main.c,v 1.33 2010/05/26 21:43:36 dmh Exp $ */
+
+#include "includes.h"
+#include "offsets.h"
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
 #endif
-#include "includes.h"
-#include "offsets.h"
 
 /* Default is netcdf-3 mode 1 */
 #define DFALTCMODE 0
@@ -42,6 +44,7 @@ char *datasetname; /* name from the netcdf <name> {} */
 
 /* Misc. flags*/
 int usingclassic;
+int allowspecial; /* are special attributes ok to use */
 
 extern FILE *ncgin;
 
@@ -51,11 +54,7 @@ void usage ( void );
 int main ( int argc, char** argv );
 
 /* Define tables vs modes for legal -k values*/
-#define NKVALUES 14
-struct Kvalues {
-char* name;
-int mode;
-} legalkinds[NKVALUES] = {
+struct Kvalues legalkinds[NKVALUES] = {
     {"1", 0},
     {"classic", 0},
 
@@ -68,6 +67,8 @@ int mode;
     {"3", NC_NETCDF4},
     {"hdf5", NC_NETCDF4},
     {"netCDF-4", NC_NETCDF4},
+    {"netcdf-4", NC_NETCDF4},
+    {"netcdf4", NC_NETCDF4},
     {"enhanced", NC_NETCDF4},
     /* NetCDF-4 HDF5 format, but using only nc3 data model */
     {"4", NC_NETCDF4 | NC_CLASSIC_MODEL},
@@ -304,11 +305,6 @@ main(
     }
 #endif
 
-    if(f77_flag && c_flag) {
-	derror("Only one of -lc or -lf may be specified");
-	return(8);
-      }
-
     argc -= optind;
     argv += optind;
 
@@ -331,8 +327,21 @@ main(
 
     /* Initially set up the cmode value and related items*/
     if(kflag_flag == 0) cmode_modifier = DFALTCMODE;
-    usingclassic = ((cmode_modifier & NC_NETCDF4) == 0);
-    if((cmode_modifier & NC_CLASSIC_MODEL) != 0) usingclassic = 1;
+
+    usingclassic = 0;
+    allowspecial = 0;
+
+    /* Do first pass on flags */
+    if((cmode_modifier & NC_NETCDF4) != 0) {
+	allowspecial = 1;
+	if((cmode_modifier & NC_CLASSIC_MODEL)) {
+	    usingclassic = 1;
+	} else {
+	    usingclassic = 0;
+	}	    
+    } else {
+	usingclassic = 1;
+    }
 
     /* F77 || STD java => classic */
     if(f77_flag || java_flag) {
@@ -347,20 +356,37 @@ main(
     if(debug >= 2) {ncgdebug=1;}
     if(ncgparse() != 0) return 1;
 
-    /* Recompute mode flag*/
-    usingclassic = ((cmode_modifier & NC_NETCDF4) == 0);
-    if((cmode_modifier & NC_CLASSIC_MODEL) != 0) usingclassic = 1;
-
-    if(f77_flag || java_flag) {
-	usingclassic=1;
-	cmode_modifier &= ~(NC_NETCDF4);
+    /* Recompute flags */
+    if((cmode_modifier & NC_NETCDF4) != 0) {
+	allowspecial = 1;
+	if((cmode_modifier & NC_CLASSIC_MODEL)) {
+	    usingclassic = 1;
+	} else {
+	    usingclassic = 0;
+	}	    
+    } else {
+	usingclassic = 1;
     }
 
+    /* Complain if still usingclassic =1 && a cdf4
+       construct was used
+    */
+    if(usingclassic && getmarkcdf4() != NULL) {
+	verror(getmarkcdf4());
+	return 1;
+    }
+
+
+#ifndef USE_NETCDF4
+    allowspecial = 0;
+#endif
+
     processsemantics();
     define_netcdf();
 
     return 0;
 }
+END_OF_MAIN();
 
 void
 init_netcdf(void) /* initialize global counts, flags */
@@ -369,6 +395,7 @@ init_netcdf(void) /* initialize global counts, flags */
     memset((void*)&nullconstant,0,sizeof(Constant));
     fillconstant = nullconstant;
     fillconstant.nctype = NC_FILLVALUE;
+
     codebuffer = bbNew();
     stmt = bbNew();
 }
