@@ -3,7 +3,7 @@
 /*********************************************************************
  *   Copyright 1993, UCAR/Unidata
  *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
- *   $Header: /upc/share/CVS/netcdf-3/ncgen/ncgen.h,v 1.12 2010/04/04 19:39:53 dmh Exp $
+ *   $Header: /upc/share/CVS/netcdf-3/ncgen/ncgen.h,v 1.18 2010/06/01 15:34:53 ed Exp $
  *********************************************************************/
 
 
@@ -34,55 +34,19 @@
 #define NC_PRIM     108 /*Including NC_STRING */
 #define NC_STRUCT  NC_COMPOUND /* alias */
 
-#ifndef USE_NETCDF4
-#define NC_CLASSIC_MODEL 0x0100
-#define NC_NETCDF4      0x1000  /* Use netCDF-4/HDF5 format */
-/* Define what we would otherwise need from netcdf4's netcdf.h*/
-typedef struct {
-    size_t len; /* Length of VL data (in base type units) */
-    void *p;    /* Pointer to VL data */
-} nc_vlen_t;
-#define	NC_UBYTE 	7	/* unsigned 1 byte int */
-#define	NC_USHORT 	8	/* unsigned 2-byte int */
-#define	NC_UINT 	9	/* unsigned 4-byte int */
-#define	NC_INT64 	10	/* signed 8-byte int */
-#define	NC_UINT64 	11	/* unsigned 8-byte int */
-#define	NC_STRING 	12	/* string */
-#define	NC_VLEN 	13	/* used internally for vlen types */
-#define	NC_OPAQUE 	14	/* used internally for opaque types */
-#define	NC_ENUM 	15	/* used internally for enum types */
-#define	NC_COMPOUND 	16	/* used internally for compound types */
-
-#define NC_MAX_BYTE 127
-#define NC_MIN_BYTE (-NC_MAX_BYTE-1)
-#define NC_MAX_CHAR 255
-#define NC_MAX_SHORT 32767
-#define NC_MIN_SHORT (-NC_MAX_SHORT - 1)
-#define NC_MAX_INT 2147483647
-#define NC_MIN_INT (-NC_MAX_INT - 1)
-#define NC_MAX_FLOAT 3.402823466e+38f
-#define NC_MIN_FLOAT (-NC_MAX_FLOAT)
-#define NC_MAX_DOUBLE 1.7976931348623157e+308 
-#define NC_MIN_DOUBLE (-NC_MAX_DOUBLE)
-#define NC_MAX_UBYTE NC_MAX_CHAR
-#define NC_MAX_USHORT 65535U
-#define NC_MAX_UINT 4294967295U
-#define NC_MAX_INT64 (9223372036854775807LL)
-#define NC_MIN_INT64 (-9223372036854775807LL-1)
-#define NC_MAX_UINT64 (18446744073709551615ULL)
-
-#define NC_FILL_UBYTE   (255)
-#define NC_FILL_USHORT  (65535)
-#define NC_FILL_UINT    (4294967295U)
-#define NC_FILL_INT64   ((long long)-9223372036854775806LL)
-#define NC_FILL_UINT64  ((unsigned long long)18446744073709551614ULL)
-#define NC_FILL_STRING  ""
-
-#endif
-
 /* Extend nc types with generic fill value*/
 #define NC_FILLVALUE    31
 
+/* Must be a better way to do this */
+#ifndef INFINITE
+#define NANF (0.0f/0.0f)
+#define NAN (0.0/0.0)
+#define INFINITEF (1.0f/0.0f)
+#define NEGINFINITEF (-INFINITEF)
+#define INFINITE (1.0/0.0)
+#define NEGINFINITE (-INFINITEF)
+#endif
+
 /* nc_class is one of:
         NC_GRP NC_DIM NC_VAR NC_ATT NC_TYPE
 */
@@ -105,17 +69,27 @@ various C global variables
 
 /* Define a bit set for indicating which*/
 /* specials were explicitly specified*/
-#define _STORAGE_FLAG       0x01
-#define _CHUNKSIZE_FLAG     0x02
-#define _FLETCHER32_FLAG    0x04
-#define _DEFLATE_FLAG       0x08
-#define _SHUFFLE_FLAG       0x10
-#define _ENDIAN_FLAG        0x20
-#define _NOFILL_FLAG        0x40
+#define _STORAGE_FLAG       0x001
+#define _CHUNKSIZES_FLAG    0x002
+#define _FLETCHER32_FLAG    0x004
+#define _DEFLATE_FLAG       0x008
+#define _SHUFFLE_FLAG       0x010
+#define _ENDIAN_FLAG        0x020
+#define _NOFILL_FLAG        0x040
+#define _FILLVALUE_FLAG     0x080
+#define _FORMAT_FLAG        0x100
+
+struct Kvalues {
+char* name;
+int mode;
+};
+
+#define NKVALUES 16
+extern struct Kvalues legalkinds[NKVALUES];
 
 /* Note: non-variable specials (e.g. _Format) are not included in this struct*/
 typedef struct Specialdata {
-    unsigned long flags;
+    int flags;
     Datalist*     _Fillvalue;
     int           _Storage;      /* NC_CHUNKED | NC_CONTIGUOUS*/
     size_t*       _ChunkSizes;     /* NULL => defaults*/
@@ -131,14 +105,13 @@ typedef struct Specialdata {
 /* (Note: the netcdf type system is deficient here)*/
 typedef struct Dimset {
     int		     ndims;
-    struct Symbol*   dimsyms[NC_MAX_DIMS]; /* Symbol for dimension*/
+    struct Symbol*   dimsyms[NC_MAX_VAR_DIMS]; /* Symbol for dimension*/
 } Dimset;
 
 typedef struct Diminfo {
     int   isconstant; /* separate constant from named dimension*/
     size_t  unlimitedsize; /* if unlimited */
     size_t  declsize; /* 0 => unlimited/unspecified*/
-//    size_t  unlimitedsize; /* computed unlimited size  */
 } Diminfo;
 
 typedef struct Attrinfo {
