@@ -10,6 +10,9 @@
 #include <unistd.h>
 #endif
 #include <string.h>
+#ifdef HAVE_GETOPT_H
+#include <getopt.h>
+#endif
 
 #ifdef __hpux
 #include <locale.h>
@@ -77,6 +80,9 @@ main(
 	int argc,
 	char *argv[])
 {
+/*    MSC_EXTRA extern int optind;
+    MSC_EXTRA extern int opterr;
+    MSC_EXTRA extern char *optarg;*/
     int any_error;
     int c;
     FILE *fp;
@@ -227,3 +233,4 @@ main(
 	return 1;
     return 0;
 }
+END_OF_MAIN();
