@@ -3,6 +3,11 @@
  *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
  *   $Header $
  *********************************************************************/
+#ifndef _EMALLOC_H_
+#define _EMALLOC_H_
+
+#include <config.h>
+#include <stdlib.h> /* free() */
 
 #undef PROTO
 #ifndef NO_HAVE_PROTOTYPES 
@@ -16,14 +21,15 @@ extern "C" {
 #endif
 
 extern void	*emalloc	PROTO((
-				       int size
+				       size_t size
 				       ));
 
 extern void	*erealloc	PROTO((
 				       void *ptr,
-				       int size
+				       size_t size
 				       ));
 
 #ifdef __cplusplus
 }
 #endif
+#endif /* !_EMALLOC_H_ */
