@@ -1,6 +1,7 @@
 /* Copyright 2009, UCAR/Unidata and OPeNDAP, Inc.
    See the COPYRIGHT file for more information. */
 
+#include "config.h"
 #include <stdio.h>
 #include <fcntl.h>
 #include <errno.h>
@@ -29,9 +30,8 @@
 #define TMPPATH2 "./"
 #endif
 
-/* Define default rc files */
-#define DODSRC ".dodsrc"
-#define OPENDAPRC ".opendap.rc"
+/* Define default rc files and aliases*/
+static char* rcfilenames[3] = {".dodsrc",".httprc",NULL};
 
 static int ocextractdds(OCstate*,OCtree*);
 static char* constraintescape(const char* url);
@@ -60,7 +60,7 @@ mktemp(tmpl); ret=open(tmpl,O_RDWR|O_BINARY|O_CREAT|O_EXCL|_O_SHORT_LIVED, _S_IR
 #endif
 
 /* Global flags*/
-static int oc_big_endian;
+static int oc_big_endian; /* what is this machine? */
 int oc_network_order; /* network order is big endian */
 int oc_invert_xdr_double;
 int oc_curl_file_supported;
@@ -72,6 +72,7 @@ ocinternalinitialize(void)
     int stat = OC_NOERR;
 
     /* Compute if we are same as network order v-a-v xdr */
+    
 #ifdef XDRBYTEORDER
     {
         XDR xdrs;
@@ -90,8 +91,9 @@ ocinternalinitialize(void)
         int testint = 0x00000001;
         char *byte = (char *)&testint;
         oc_big_endian = (byte[0] == 0 ? 1 : 0);
-        oc_network_order = oc_big_endian;
+	oc_network_order = oc_big_endian;
     }
+
 #endif /*XDRBYTEORDER*/
     {
         /* It turns out that various machines
@@ -154,39 +156,42 @@ ocinternalinitialize(void)
     {
         char* path = NULL;
         char* homepath = NULL;
+	char** alias;
 	FILE* f = NULL;
         /* locate the configuration files: . first, then $HOME */
-        path = (char*)malloc(strlen("./")+strlen(DODSRC)+1);
-	if(path == NULL) return OC_ENOMEM;
-        strcpy(path,"./");
-        strcat(path,DODSRC);
-	/* see if file is readable */
-	f = fopen(path,"r");
-	if(f == NULL) {
+	for(alias=rcfilenames;*alias;alias++) {
+            path = (char*)malloc(strlen("./")+strlen(*alias)+1);
+	    if(path == NULL) return OC_ENOMEM;
+            strcpy(path,"./");
+            strcat(path,*alias);
+  	    /* see if file is readable */
+	    f = fopen(path,"r");
+	    if(f != NULL) break;
 	    /* try $HOME */
             homepath = getenv("HOME");
             if (homepath!= NULL) {
-	       if(path != NULL) free(path);
-	       path = (char*)malloc(strlen(homepath)+1+strlen(DODSRC)+1);
-	       if(path == NULL) return OC_ENOMEM;
-	       strcpy(path,homepath);
-	       strcat(path,"/");
-	       strcat(path,DODSRC);
-	       f = fopen(path,"r");
+		if(path != NULL) free(path);
+	        path = (char*)malloc(strlen(homepath)+1+strlen(*alias)+1);
+	        if(path == NULL) return OC_ENOMEM;
+	        strcpy(path,homepath);
+	        strcat(path,"/");
+	        strcat(path,*alias);
+		f = fopen(path,"r");
+		if(f != NULL) break;
             }
-        }
+	}
         if(f == NULL) {
-	    oc_log(LOGWARN,"Cannot find runtime .dodsrc configuration file");
+            oc_log(LOGWARN,"Cannot find runtime configuration file");
 	} else {
        	    fclose(f);
             if(ocdebug > 1)
 		fprintf(stderr, "DODS RC file: %s\n", path);
-            if(ocdodsrc_read(path) == 0)
+            if(ocdodsrc_read(*alias,path) == 0)
 	        oc_log(LOGERR, "Error parsing %s\n",path);
         }
         if(path != NULL) {free(path) ; path = NULL;}
     }
-    return THROW(stat);
+    return OCTHROW(stat);
 }
 
 /**************************************************/
@@ -195,27 +200,24 @@ ocopen(OCstate** statep, const char* url)
 {
     int stat = OC_NOERR;
     OCstate * state = NULL;
-    DAPURL tmpurl;
+    OCURI* tmpurl;
     CURL* curl = NULL; /* curl handle*/
 
-    memset((void*)&tmpurl,0,sizeof(tmpurl));
-
-    if(!dapurlparse(url,&tmpurl)) {THROWCHK(stat=OC_EBADURL); goto fail;}
+    if(!ocuriparse(url,&tmpurl)) {OCTHROWCHK(stat=OC_EBADURL); goto fail;}
     
     stat = occurlopen(&curl);
-    if(stat != OC_NOERR) {THROWCHK(stat); goto fail;}
+    if(stat != OC_NOERR) {OCTHROWCHK(stat); goto fail;}
 
     state = (OCstate*)ocmalloc(sizeof(OCstate)); /* ocmalloc zeros memory*/
-    if(state == NULL) {THROWCHK(stat=OC_ENOMEM); goto fail;}
+    if(state == NULL) {OCTHROWCHK(stat=OC_ENOMEM); goto fail;}
 
     /* Setup DAP state*/
     state->magic = OCMAGIC;
     state->curl = curl;
     state->trees = oclistnew();
     state->contentlist = NULL;
-    state->url = tmpurl;
-    state->clientparams = ocparamdecode(state->url.params);
-    if(state->clientparams == NULL) {
+    state->uri = tmpurl;
+    if(!ocuridecodeparams(state->uri)) {
 	oc_log(LOGWARN,"Could not parse client parameters");
     }
     state->packet = ocbytesnew();
@@ -225,13 +227,13 @@ ocopen(OCstate** statep, const char* url)
     ocsetcurlproperties(state);
 
     if(statep) *statep = state;
-    return THROW(stat);   
+    return OCTHROW(stat);   
 
 fail:
-    dapurlclear(&tmpurl);
+    ocurifree(tmpurl);
     if(state != NULL) ocfree(state);
     if(curl != NULL) occurlclose(curl);
-    return THROW(stat);
+    return OCTHROW(stat);
 }
 
 OCerror
@@ -250,6 +252,12 @@ ocfetch(OCstate* state, const char* constraint, OCdxd kind, OCnode** rootp)
     if(tree->constraint == NULL)
 	tree->constraint = nulldup(constraint);
 
+    /* Set curl properties: pwd, flags, proxies, ssl */
+    if((stat=ocset_user_password(state))!= OC_NOERR) goto fail;
+    if((stat=ocset_curl_flags(state)) != OC_NOERR) goto fail;
+    if((stat=ocset_proxy(state)) != OC_NOERR) goto fail;
+    if((stat=ocset_ssl(state)) != OC_NOERR) goto fail;
+
     ocbytesclear(state->packet);
 
     switch (kind) {
@@ -273,7 +281,7 @@ ocfetch(OCstate* state, const char* constraint, OCdxd kind, OCnode** rootp)
            so that DRNO can reference it*/
         /* Make the tmp file*/
         stat = createtempfile(state,tree);
-        if(stat) {THROWCHK(stat); goto unwind;}
+        if(stat) {OCTHROWCHK(stat); goto unwind;}
         stat = readDATADDS(state,tree);
 	if(stat == OC_NOERR) {
             /* Separate the DDS from data and return the dds;
@@ -298,7 +306,7 @@ ocfetch(OCstate* state, const char* constraint, OCdxd kind, OCnode** rootp)
 	} else {
 	    oc_log(LOGWARN,"oc_open: Could not read url");
 	}
-	return THROW(stat);
+	return OCTHROW(stat);
     }
 
     tree->nodes = NULL;
@@ -309,7 +317,7 @@ ocfetch(OCstate* state, const char* constraint, OCdxd kind, OCnode** rootp)
 		  state->error.code,	
 		  (state->error.message?state->error.message:""));
     }
-    if(stat) {THROWCHK(stat); goto unwind;}
+    if(stat) {OCTHROWCHK(stat); goto unwind;}
     root = tree->root;
     /* make sure */
     tree->root = root;
@@ -319,15 +327,15 @@ ocfetch(OCstate* state, const char* constraint, OCdxd kind, OCnode** rootp)
     switch (kind) {
     case OCDAS:
         if(root->octype != OC_Attributeset)
-	    {THROWCHK(stat=OC_EDAS); goto unwind;}
+	    {OCTHROWCHK(stat=OC_EDAS); goto unwind;}
 	break;
     case OCDDS:
         if(root->octype != OC_Dataset)
-	    {THROWCHK(stat=OC_EDDS); goto unwind;}
+	    {OCTHROWCHK(stat=OC_EDDS); goto unwind;}
 	break;
     case OCDATADDS:
         if(root->octype != OC_Dataset)
-	    {THROWCHK(stat=OC_EDATADDS); goto unwind;}
+	    {OCTHROWCHK(stat=OC_EDATADDS); goto unwind;}
 	/* Modify the tree kind */
 	tree->dxdclass = OCDATADDS;
 	break;
@@ -372,7 +380,8 @@ ocfetch(OCstate* state, const char* constraint, OCdxd kind, OCnode** rootp)
 
 unwind:
     ocfreetree(tree);
-    return THROW(stat);
+fail:
+    return OCTHROW(stat);
 }
 
 void
@@ -388,7 +397,7 @@ occlose(OCstate* state)
 	ocfreeroot(root);
     }
     oclistfree(state->trees);
-    dapurlclear(&state->url);
+    ocurifree(state->uri);
     ocbytesfree(state->packet);
     ocfree(state->error.code);
     ocfree(state->error.message);
@@ -401,8 +410,18 @@ occlose(OCstate* state)
 	    curr = next;
 	}
     }
+    ocfree(state->curlflags.useragent);
+    ocfree(state->curlflags.cookiejar);
+    ocfree(state->curlflags.cookiefile);
+    ocfree(state->ssl.certificate);
+    ocfree(state->ssl.key);
+    ocfree(state->ssl.keypasswd);
+    ocfree(state->ssl.cainfo);
+    ocfree(state->ssl.capath); 
+    ocfree(state->proxy.host);
+    ocfree(state->creds.username);
+    ocfree(state->creds.password);
     if(state->curl != NULL) occurlclose(state->curl);
-    if(state->clientparams != NULL) ocparamfree(state->clientparams);
     ocfree(state);
 }
 
@@ -416,7 +435,7 @@ ocextractdds(OCstate* state, OCtree* tree)
     ocbytesclear(state->packet);
     rewind(tree->data.file);
     do {
-	char chunk[128];
+	char chunk[1024];
 	size_t count;
 	/* read chunks of the file until we find the separator*/
         count = fread(chunk,1,sizeof(chunk),tree->data.file);
@@ -459,7 +478,7 @@ ocextractdds(OCstate* state, OCtree* tree)
     }
 #endif
     if(tree->text == NULL) stat = OC_EDATADDS;
-    return THROW(stat);
+    return OCTHROW(stat);
 }
 
 #ifdef OC_DISK_STORAGE
@@ -550,7 +569,10 @@ ocupdatelastmodifieddata(OCstate* state)
 {
     OCerror status = OC_NOERR;
     long lastmodified;
-    status = ocfetchlastmodified(state->curl, state->url.base, &lastmodified);
+    char* base = NULL;
+    base = ocuribuild(state->uri,NULL,NULL,0);
+    status = ocfetchlastmodified(state->curl, base, &lastmodified);
+    free(base);
     if(status == OC_NOERR) {
 	state->datalastmodified = lastmodified;
     }
@@ -563,47 +585,22 @@ ocupdatelastmodifieddata(OCstate* state)
 static void
 ocsetcurlproperties(OCstate* state)
 {
-    CURL* curl = state->curl;
     CURLcode cstat = CURLE_OK;
-    int stat = OC_NOERR;
 
     /* process the triple store wrt to this state */
     if(ocdodsrc_process(state) != OC_NOERR) {
-	oc_log(LOGERR,"Malformed .dodsrc");
+	oc_log(LOGERR,"Malformed .opendaprc configuration file");
 	goto fail;
     }
-    /* Set username+password from .dodsrc */
-    stat=ocset_user_password(curl,state->creds.username,
-                                  state->creds.password);
-    if(stat != OC_NOERR) goto fail;    
-
-    if (occredentials_in_url(state->url.url)) {
-	/* this overrides .dodsrc */
-        char *result_url = NULL;
-        char* userName = NULL;
-        char* password = NULL;
-        if (ocextract_credentials(state->url.url, &userName, &password, &result_url) != OC_NOERR)
-            goto fail;
-	dapurlclear(&state->url);
-	dapurlparse(result_url,&state->url);
-	/* this overrides .dodsrc */
-        if(password != NULL && strlen(password) > 0) {
+    if(state->creds.username == NULL && state->creds.password == NULL) {
+        if(state->uri->user != NULL && state->uri->password != NULL) {
+	    /* this overrides .dodsrc */
             if(state->creds.password) free(state->creds.password);
-            state->creds.password = password;
-	}
-        if(userName != NULL && strlen(userName) > 0) {
+            state->creds.password = nulldup(state->uri->password);
             if(state->creds.username) free(state->creds.username);
-            state->creds.username = userName;
+            state->creds.username = nulldup(state->uri->user);
 	}
     }
-
-    /* Set curl properties */
-    if((stat=ocset_curl_flags(curl,state)) != OC_NOERR) goto fail;
-    /* Set curl proxy */
-    if((stat=ocset_proxy(curl,state)) != OC_NOERR) goto fail;
-    /* Set curl ssl */
-    if((stat=ocset_ssl(curl,state)) != OC_NOERR) goto fail;
-
     return;
 
 fail:
